==> jc-1.4.0.tar.gz: java/util/PropertyPermissionCollection.h <==
// class java.util.PropertyPermissionCollection

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection
// @dep_class 5a5ebdb5ccda3ba4 java_util_PropertyPermissionCollection

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_util_PropertyPermissionCollection_H_
#define _JC_java_util_PropertyPermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_util_PropertyPermissionCollection$sub_refs	_jc_java_util_PropertyPermissionCollection$sub_refs;
typedef struct _jc_java_util_PropertyPermissionCollection$sub_nonrefs	_jc_java_util_PropertyPermissionCollection$sub_nonrefs;
typedef struct _jc_java_util_PropertyPermissionCollection$refs	_jc_java_util_PropertyPermissionCollection$refs;
typedef struct _jc_java_util_PropertyPermissionCollection$nonrefs	_jc_java_util_PropertyPermissionCollection$nonrefs;
typedef struct _jc_java_util_PropertyPermissionCollection$object	_jc_java_util_PropertyPermissionCollection$object;

typedef struct _jc_java_util_PropertyPermissionCollection$fields_struct	_jc_java_util_PropertyPermissionCollection$fields_struct;
typedef const struct _jc_java_util_PropertyPermissionCollection$vmethods	_jc_java_util_PropertyPermissionCollection$vmethods;
typedef const struct _jc_java_util_PropertyPermissionCollection$vtable	_jc_java_util_PropertyPermissionCollection$vtable;
typedef const struct _jc_java_util_PropertyPermissionCollection$vtype	_jc_java_util_PropertyPermissionCollection$vtype;

// Class fields structure
struct _jc_java_util_PropertyPermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_PropertyPermissionCollection$fields_struct _jc_java_util_PropertyPermissionCollection$class_fields;

// Constructors
extern void _jc_java_util_PropertyPermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *);

// Virtual methods
extern void _jc_java_util_PropertyPermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_object *_jc_java_util_PropertyPermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *);
extern jboolean _jc_java_util_PropertyPermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern void _jc_java_util_PropertyPermissionCollection$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_PropertyPermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *);
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *);
};

// Vtable
struct _jc_java_util_PropertyPermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_util_PropertyPermissionCollection$vmethods	java_util_PropertyPermissionCollection;
};

// Vtype
struct _jc_java_util_PropertyPermissionCollection$vtype {
	_jc_type			type;
	_jc_java_util_PropertyPermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_PropertyPermissionCollection$sub_refs {
	struct _jc_java_util_Hashtable$object	*permissions;
};

// Reference instance fields (object)
struct _jc_java_util_PropertyPermissionCollection$refs {
    _jc_java_util_PropertyPermissionCollection$sub_refs	java_util_PropertyPermissionCollection;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_PropertyPermissionCollection$sub_nonrefs {
	jboolean	all__5fallowed;
};

// Non-reference instance fields (object)
struct _jc_java_util_PropertyPermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_util_PropertyPermissionCollection$sub_nonrefs	java_util_PropertyPermissionCollection;
};

// Object instance structure
struct _jc_java_util_PropertyPermissionCollection$object {
	_jc_java_util_PropertyPermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_PropertyPermissionCollection$vtype	*vtype;
	_jc_java_util_PropertyPermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_PropertyPermissionCollection$vtype _jc_java_util_PropertyPermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_PropertyPermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_PropertyPermissionCollection$class_object;

#endif	/* _JC_java_util_PropertyPermissionCollection_H_ */

==> jc-1.4.6.tar.gz: java/util/PropertyPermissionCollection.h <==
// class java.util.PropertyPermissionCollection

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection
// @dep_class 5a5ebdb5ccda3ba4 java_util_PropertyPermissionCollection

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_util_PropertyPermissionCollection_H_
#define _JC_java_util_PropertyPermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_util_PropertyPermissionCollection$sub_refs	_jc_java_util_PropertyPermissionCollection$sub_refs;
typedef struct _jc_java_util_PropertyPermissionCollection$sub_nonrefs	_jc_java_util_PropertyPermissionCollection$sub_nonrefs;
typedef struct _jc_java_util_PropertyPermissionCollection$refs	_jc_java_util_PropertyPermissionCollection$refs;
typedef struct _jc_java_util_PropertyPermissionCollection$nonrefs	_jc_java_util_PropertyPermissionCollection$nonrefs;
typedef struct _jc_java_util_PropertyPermissionCollection$object	_jc_java_util_PropertyPermissionCollection$object;

typedef struct _jc_java_util_PropertyPermissionCollection$fields_struct	_jc_java_util_PropertyPermissionCollection$fields_struct;
typedef const struct _jc_java_util_PropertyPermissionCollection$vmethods	_jc_java_util_PropertyPermissionCollection$vmethods;
typedef const struct _jc_java_util_PropertyPermissionCollection$vtable	_jc_java_util_PropertyPermissionCollection$vtable;
typedef const struct _jc_java_util_PropertyPermissionCollection$vtype	_jc_java_util_PropertyPermissionCollection$vtype;

// Class fields structure
struct _jc_java_util_PropertyPermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_PropertyPermissionCollection$fields_struct _jc_java_util_PropertyPermissionCollection$class_fields;

// Constructors
extern void _jc_java_util_PropertyPermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_PropertyPermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_PropertyPermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_PropertyPermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_PropertyPermissionCollection$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_util_PropertyPermissionCollection$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_PropertyPermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_PropertyPermissionCollection$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_PropertyPermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_util_PropertyPermissionCollection$vmethods	java_util_PropertyPermissionCollection;
};

// Vtype
struct _jc_java_util_PropertyPermissionCollection$vtype {
	_jc_type			type;
	_jc_java_util_PropertyPermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_PropertyPermissionCollection$sub_refs {
	struct _jc_java_util_Hashtable$object	*permissions;
};

// Reference instance fields (object)
struct _jc_java_util_PropertyPermissionCollection$refs {
    _jc_java_util_PropertyPermissionCollection$sub_refs	java_util_PropertyPermissionCollection;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_PropertyPermissionCollection$sub_nonrefs {
	jboolean	all__5fallowed;
};

// Non-reference instance fields (object)
struct _jc_java_util_PropertyPermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_util_PropertyPermissionCollection$sub_nonrefs	java_util_PropertyPermissionCollection;
};

// Object instance structure
struct _jc_java_util_PropertyPermissionCollection$object {
	_jc_java_util_PropertyPermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_PropertyPermissionCollection$vtype	*vtype;
	_jc_java_util_PropertyPermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_PropertyPermissionCollection$vtype _jc_java_util_PropertyPermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_PropertyPermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_PropertyPermissionCollection$class_object;

#endif	/* _JC_java_util_PropertyPermissionCollection_H_ */
